@@ -1,4 +1,5 @@
 import datetime
+import sys
 
 from je_api_testka.requests_wrapper.requests_http_method_wrapper import api_tester_method
 from requests.structures import CaseInsensitiveDict
@@ -50,21 +51,36 @@ def get_response(response, start_time, end_time):
 def test_api_method(http_method: str, test_url: str,
                     soap: bool = False, record_request_info: bool = True,
                     clean_record: bool = False, result_check_dict: dict = None, **kwargs):
-    start_time = datetime.datetime.now()
-    if soap is False:
-        response = api_tester_method(http_method, test_url=test_url, **kwargs)
-    else:
-        headers = CaseInsensitiveDict()
-        headers["Content-Type"] = "application/soap+xml"
-        return test_api_method(http_method, test_url=test_url, headers=headers, **kwargs)
-    end_time = datetime.datetime.now()
-    response_data = get_response(response, start_time, end_time)
-    if record_request_info:
-        test_record.record_list.append(response_data)
-    elif clean_record:
-        test_record.clean_record()
-    if result_check_dict is None:
-        return {"response": response, "response_data": response_data}
-    else:
-        check_result(response_data, result_check_dict)
-        return {"response": response, "response_data": response_data}
+    try:
+        start_time = datetime.datetime.now()
+        if soap is False:
+            response = api_tester_method(http_method, test_url=test_url, **kwargs)
+        else:
+            headers = CaseInsensitiveDict()
+            headers["Content-Type"] = "application/soap+xml"
+            return test_api_method(http_method, test_url=test_url, headers=headers, **kwargs)
+        end_time = datetime.datetime.now()
+        response_data = get_response(response, start_time, end_time)
+        if record_request_info:
+            test_record.record_list.append(response_data)
+        elif clean_record:
+            test_record.clean_record()
+        if result_check_dict is None:
+            return {"response": response, "response_data": response_data}
+        else:
+            check_result(response_data, result_check_dict)
+            return {"response": response, "response_data": response_data}
+    except Exception as error:
+        print(repr(error), file=sys.stderr)
+        test_record.error_record_list.append([
+            {
+                "http_method": http_method,
+                "test_url": test_url,
+                "soap": soap,
+                "record_request_info": record_request_info,
+                "clean_record": clean_record,
+                "result_check_dict": result_check_dict
+             },
+            repr(error)]
+        )
+
