@@ -3,11 +3,12 @@ import sys
 from je_api_testka.requests_wrapper.request_method import test_api_method
 from je_api_testka.utils.exception.api_test_exceptions import APITesterExecuteException
 from je_api_testka.utils.exception.api_test_eceptions_tag import executor_data_error
-from je_api_testka.utils.test_record.record_test_result_class import test_record
+from je_api_testka.utils.html_report.html_report_generate import generate_html
 
 event_dict = {
     # test api
     "test_api_method": test_api_method,
+    "generate_html": generate_html,
 }
 
 
@@ -23,12 +24,8 @@ def execute_action(action_list: list):
     execute_record_string = ""
     event_response_list = []
     for action in action_list:
-        try:
-            event_response = execute_event(action)
-            print("execute: ", str(action))
-            execute_record_string = "".join(execute_record_string)
-            event_response_list.append(event_response)
-        except Exception as error:
-            print(repr(error), file=sys.stderr)
-            test_record.error_record_list.append([action, repr(error)])
+        event_response = execute_event(action)
+        print("execute: ", str(action))
+        execute_record_string = "".join(execute_record_string)
+        event_response_list.append(event_response)
     return execute_record_string, event_response_list
